Learn R Programming

limorhyde2 (version 0.1.1)

GSE34018: Gene expression data for GSE34018

Description

Data are based on total RNA, measured by microarray, obtained from livers of wild-type and liver-specific Reverb alpha/beta double knockout mice at various times in a 12h:12h light:dark cycle. To save space and time, the data include only a subset of genes, and so are mainly useful for examples of how to use limorhyde2.

Usage

GSE34018

Arguments

Format

A list with two elements:

  • y: Matrix of normalized, log-transformed expression values. Rows correspond to genes (rownames are Entrez Gene IDs) and columns to samples.

  • metadata: data.table with one row per sample. time is in hours.

See Also

GSE54650, getModelFit()